package com.acabezas.ehealth_doctor_app.home;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.support.design.widget.NavigationView;
import android.support.design.widget.TabLayout;
import android.support.v4.view.GravityCompat;
import android.support.v4.view.ViewPager;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.LinearLayout;

import com.acabezas.ehealth_doctor_app.R;
import com.acabezas.ehealth_doctor_app.core.StartVideoConferenceCallback;
import com.acabezas.ehealth_doctor_app.home.pacient_waiting_fragment.PacientWaitingFragment;
import com.acabezas.ehealth_doctor_app.home.scheduled_appointments_fragment.ScheduledAppointmentsFragment;
import com.acabezas.ehealth_doctor_app.login.LoginActivity;
import com.acabezas.ehealth_doctor_app.my_account.MyAccountActivity;
import com.acabezas.ehealth_doctor_app.tools.AlertDialogCallback;
import com.acabezas.ehealth_doctor_app.tools.Tools;

import butterknife.BindView;
import butterknife.ButterKnife;

public class HomeActivity extends AppCompatActivity implements HomeContracts.View, NavigationView.OnNavigationItemSelectedListener{

    @BindView(R.id.toolbar)
    Toolbar toolbar;
    @BindView(R.id.tabs)
    TabLayout tabLayout;
    @BindView(R.id.viewpager)
    ViewPager viewPager;
    private PacientWaitingFragment pacientWaitingFragment;

    private HomeContracts.Presenter presenter;

    private void setupViewPager(ViewPager viewPager) {
        ViewPagerAdapter adapter = new ViewPagerAdapter(getSupportFragmentManager());
        pacientWaitingFragment = new PacientWaitingFragment();
        pacientWaitingFragment.setCallback(new StartVideoConferenceCallback() {
            @Override
            public void goToVideoConference() {
                presenter.goToVideoConference();
            }
        });
        adapter.addFragment(pacientWaitingFragment, "Wait List");
        adapter.addFragment(new ScheduledAppointmentsFragment(), "Appointments");
        viewPager.setAdapter(adapter);
    }

    private void init(){

        setupViewPager(viewPager);
        tabLayout.setupWithViewPager(viewPager);
    }

    public static void startHomectivity(Activity context) {
        Intent intent = new Intent(context, HomeActivity.class);
        context.startActivity(intent);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_nav);
        ButterKnife.bind(this);
        setSupportActionBar(toolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        init();
        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        ActionBarDrawerToggle toggle = new ActionBarDrawerToggle(
                this, drawer, toolbar, R.string.navigation_drawer_open, R.string.navigation_drawer_close);
        drawer.addDrawerListener(toggle);
        toggle.syncState();

        NavigationView navigationView = (NavigationView) findViewById(R.id.nav_view);
        navigationView.setItemIconTintList(null);
        navigationView.setNavigationItemSelectedListener(this);

        presenter = new HomePresenter(this);
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        presenter.onDestroy();

    }

    @Override
    public void showError(int error) {
        String title = getResources().getString(R.string.error_title);
        String message = "";

        switch (error){
            case 1:
                message = getResources().getString(R.string.error_video_conference);
                break;
        }

        Tools.createAlertDialog(this,title, message, new AlertDialogCallback() {
            @Override
            public void accept() {

            }
        }).show();
    }

    @Override
    public void onBackPressed() {
        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        if (drawer.isDrawerOpen(GravityCompat.START)) {
            drawer.closeDrawer(GravityCompat.START);
        } else {
            super.onBackPressed();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @SuppressWarnings("StatementWithEmptyBody")
    @Override
    public boolean onNavigationItemSelected(MenuItem item) {
        // Handle navigation view item clicks here.
        int id = item.getItemId();

        if (id == R.id.nav_home) {

        } else if(id == R.id.nav_account) {
            MyAccountActivity.startMyAccountActivity(this);
        } else if (id == R.id.nav_sign_out) {
            LoginActivity.startLoginctivity(this);
        }

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        drawer.closeDrawer(GravityCompat.START);
        return true;
    }
}
