package com.acabezas.ehealth_doctor_app.my_account;

import android.app.Activity;
import android.app.DatePickerDialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.EditText;

import com.acabezas.ehealth_doctor_app.R;
import com.acabezas.ehealth_doctor_app.tools.AlertDialogCallback;
import com.acabezas.ehealth_doctor_app.tools.Tools;
import com.acabezas.ehealth_doctor_sdk.managers.SharedPreferencesManagerImpl;

import java.util.Calendar;

import butterknife.BindView;
import butterknife.ButterKnife;

public class MyAccountActivity extends AppCompatActivity implements MyAccountContracts.View, DatePickerDialog.OnDateSetListener{
    @BindView(R.id.toolbar)
    Toolbar toolbar;
    @BindView(R.id.name_input)
    EditText name;
    @BindView(R.id.lastname1_input)
    EditText lastname1;
    @BindView(R.id.lastname2_input)
    EditText lastname2;
    @BindView(R.id.email_input)
    EditText email;
    @BindView(R.id.password_input)
    EditText password;
    @BindView(R.id.specialty_input)
    EditText specialty;
    @BindView(R.id.date_of_birth_input)
    EditText dateOfBirth;
    @BindView(R.id.update)
    Button update;
    private ProgressDialog progress;

    private MyAccountContracts.Presenter presenter;
    private DatePickerDialog datePickerDialog;

    public static void startMyAccountActivity(Activity context) {
        Intent intent = new Intent(context, MyAccountActivity.class);
        context.startActivity(intent);
    }

    private void init() {
        progress = new ProgressDialog(this, R.style.AppCompatAlertDialogStyle);
        progress.setTitle(R.string.message_title);
        String message = getResources().getString(R.string.message_please_wait);
        progress.setMessage(message);
        progress.setProgressStyle(ProgressDialog.STYLE_SPINNER);

        update.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                progress.show();
                presenter.doUpdate(name.getText().toString(),
                        lastname1.getText().toString(),
                        lastname2.getText().toString(),
                        email.getText().toString(),
                        specialty.getText().toString(),
                        dateOfBirth.getEditableText().toString(),
                        password.getEditableText().toString());
            }
        });

        Calendar currentDate = Calendar.getInstance();
        int day = currentDate.get(Calendar.DAY_OF_MONTH);
        int year = currentDate.get(Calendar.YEAR);
        int month = currentDate.get(Calendar.MONTH);

        datePickerDialog = new DatePickerDialog(
                this, MyAccountActivity.this,
                year, month, day);

        dateOfBirth.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                datePickerDialog.show();
            }
        });
        dateOfBirth.setKeyListener(null);
        dateOfBirth.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            @Override
            public void onFocusChange(View v, boolean hasFocus) {
                if (hasFocus) {
                    getWindow().setSoftInputMode(
                            WindowManager.LayoutParams.SOFT_INPUT_STATE_ALWAYS_HIDDEN
                    );

                    InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
                    imm.hideSoftInputFromWindow(findViewById(android.R.id.content).getWindowToken(), 0);
                    datePickerDialog.show();
                }
            }
        });

        toolbar.setNavigationOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MyAccountActivity.super.onBackPressed();
            }
        });
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_my_account);
        ButterKnife.bind(this);
        presenter = new MyAccountPresenter(this, SharedPreferencesManagerImpl.getInstance(getApplicationContext()));
        setSupportActionBar(toolbar);

        toolbar.setNavigationIcon(R.drawable.ic_left_arrow);

        init();
        progress.show();
        presenter.getData();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        presenter.onDestroy();
    }

    @Override
    public void showError(int error) {
        progress.dismiss();
        String title = getResources().getString(R.string.error_title);
        String message = "";

        switch (error){
            case 1:
                message = getResources().getString(R.string.error_bad_connection);
                break;
            case 2:
                message = getResources().getString(R.string.error_bad_birthdate);
                break;
            case 3:
                message = getResources().getString(R.string.error_fields_not_filled);
                break;
        }

        Tools.createAlertDialog(this,title, message, new AlertDialogCallback() {
            @Override
            public void accept() {

            }
        }).show();
    }

    @Override
    public void showSuccess() {
        progress.dismiss();
        String title = getResources().getString(R.string.message_title);
        String message = getResources().getString(R.string.message_update_profile_success);

        Tools.createAlertDialog(this,title, message, new AlertDialogCallback() {
            @Override
            public void accept() {

            }
        }).show();
    }

    @Override
    public void showUserData(String name,
                             String lastname1,
                             String lastname2,
                             String email,
                             String specialty,
                             String dateOfBirth,
                             String password) {

        progress.dismiss();
        this.name.setText(name);
        this.lastname1.setText(lastname1);
        this.lastname2.setText(lastname2);
        this.email.setText(email);
        this.specialty.setText(specialty);
        this.dateOfBirth.setText(dateOfBirth);
        this.password.setText(password);

    }

    @Override
    public void onDateSet(DatePicker view, int year, int month, int dayOfMonth) {
        dateOfBirth.setText(dayOfMonth + "/" + month+ "/" + year);
    }


}
