package com.acabezas.ehealth_doctor_app.registration;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import com.acabezas.ehealth_doctor_app.R;
import com.acabezas.ehealth_doctor_app.tools.AlertDialogCallback;
import com.acabezas.ehealth_doctor_app.tools.Tools;
import com.acabezas.ehealth_doctor_sdk.managers.SharedPreferencesManagerImpl;

import butterknife.BindView;
import butterknife.ButterKnife;

public class SignUpActivity extends AppCompatActivity implements SignUpContracts.View{

    private SignUpContracts.Presenter presenter;

    @BindView(R.id.name_input)
    EditText name;
    @BindView(R.id.lastname1_input)
    EditText lastname1;
    @BindView(R.id.lastname2_input)
    EditText lastname2;
    @BindView(R.id.email_input)
    EditText email;
    @BindView(R.id.password_input)
    EditText password;
    @BindView(R.id.specialty_input)
    EditText specialty;
    @BindView(R.id.signup)
    Button signUp;
    private ProgressDialog progress;

    public static void startSignUpActivity(Activity context) {
        Intent intent = new Intent(context, SignUpActivity.class);
        context.startActivity(intent);
    }

    private void init() {
        progress = new ProgressDialog(this, R.style.AppCompatAlertDialogStyle);
        progress.setTitle(R.string.message_title);
        String message = getResources().getString(R.string.message_please_wait);
        progress.setMessage(message);
        progress.setProgressStyle(ProgressDialog.STYLE_SPINNER);

        signUp.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                progress.show();
                presenter.doSignUp(name.getText().toString(),
                        lastname1.getText().toString(),
                        lastname2.getText().toString(),
                        email.getText().toString(),
                        password.getText().toString(),
                        specialty.getText().toString());
            }
        });
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_sign_up);
        ButterKnife.bind(this);
        init();
        presenter = new SignUpPresenter(this, SharedPreferencesManagerImpl.getInstance(getApplicationContext()));

    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        presenter.onDestroy();
    }

    @Override
    public void showError(int error) {
        progress.dismiss();
        String title = getResources().getString(R.string.error_title);
        String message = "";

        switch (error){
            case 1:
                message = getResources().getString(R.string.error_bad_connection);
                break;
            case 2:
                message = getResources().getString(R.string.error_bad_username);
                break;
            case 3:
                message = getResources().getString(R.string.error_fields_not_filled);
                break;
        }

        Tools.createAlertDialog(this,title, message, new AlertDialogCallback() {
            @Override
            public void accept() {

            }
        }).show();
    }

    @Override
    public void showSuccess() {
        progress.dismiss();
        String title = getResources().getString(R.string.message_title);
        String message = getResources().getString(R.string.message_signup_success);

        Tools.createAlertDialog(this,title, message, new AlertDialogCallback() {
            @Override
            public void accept() {
                presenter.goToHomeScreen();
            }
        }).show();
    }
}
