package com.acabezas.ehealth_doctor_app.registration;

import android.app.Activity;

import com.acabezas.ehealth_doctor_app.tools.Tools;
import com.acabezas.ehealth_doctor_sdk.managers.SharedPreferencesManager;
import com.acabezas.ehealth_doctor_sdk.model.SignUpRequest;

/**
 * Created by alexandercabezas on 14/4/18.
 */

public class SignUpPresenter implements SignUpContracts.Presenter, SignUpContracts.InteractorOutput{

    private SignUpContracts.Interactor interactor;
    private SignUpContracts.Router router;
    private SignUpContracts.View view;

    SignUpPresenter(SignUpContracts.View view, SharedPreferencesManager sharedPreferencesManager) {
        interactor = new SignUpInteractor(this, sharedPreferencesManager);
        router = new SignUpRouter((Activity) view);
        this.view = view;
    }
    @Override
    public void onDestroy() {
        interactor.unRegister();
        interactor = null;
        router.unRegister();
        router = null;
    }

    @Override
    public void goToHomeScreen() {
        router.presentHomeScreen();
    }

    @Override
    public void goToLoginScreen() {
        router.presentLoginScreen();
    }

    @Override
    public void doSignUp(String name,
                         String lastname1,
                         String lastname2,
                         String email,
                         String password,
                         String specialty) {
        if(!name.isEmpty() &&
                !lastname1.isEmpty() &&
                !lastname2.isEmpty() &&
                !email.isEmpty() &&
                !password.isEmpty() &&
                !specialty.isEmpty()) {

            if(Tools.isValidEmail(email)) {
                SignUpRequest request = new SignUpRequest();
                request.name = name;
                request.lastname1 = lastname1;
                request.lastname2 = lastname2;
                request.email = email;
                request.password = password;
                request.specialty = specialty;
                interactor.doSignUp(request);
            } else {view.showError(2);}

        } else {
            view.showError(3);
        }

    }

    @Override
    public void sigUpSuccess() {
        view.showSuccess();
    }

    @Override
    public void signUpFailed() {
        view.showError(1);
    }
}
