package com.acabezas.ehealth_doctor_sdk.data_source;

import com.acabezas.ehealth_doctor_sdk.callbacks.GetPAcientWaitingListCallback;
import com.acabezas.ehealth_doctor_sdk.callbacks.GetScheduledAppointmentsCallback;
import com.acabezas.ehealth_doctor_sdk.callbacks.GetUserProfileDataCallback;
import com.acabezas.ehealth_doctor_sdk.callbacks.LoginDoctorCallback;
import com.acabezas.ehealth_doctor_sdk.callbacks.RecoverPasswordCallback;
import com.acabezas.ehealth_doctor_sdk.callbacks.SignUpDoctorCallback;
import com.acabezas.ehealth_doctor_sdk.callbacks.UpdateUserProfileDataCallback;
import com.acabezas.ehealth_doctor_sdk.managers.NetworkManagerImpl;
import com.acabezas.ehealth_doctor_sdk.model.GenericResponse;
import com.acabezas.ehealth_doctor_sdk.model.GetAppointmentListRequest;
import com.acabezas.ehealth_doctor_sdk.model.GetPacientWaitListResponse;
import com.acabezas.ehealth_doctor_sdk.model.LoginRequest;
import com.acabezas.ehealth_doctor_sdk.model.LoginResponse;
import com.acabezas.ehealth_doctor_sdk.model.RecoverPasswordRequest;
import com.acabezas.ehealth_doctor_sdk.model.RecoverPasswordResponse;
import com.acabezas.ehealth_doctor_sdk.model.RemoveUserFromWaitListRequest;
import com.acabezas.ehealth_doctor_sdk.model.ScheduledAppointmentsResponse;
import com.acabezas.ehealth_doctor_sdk.model.SignUpRequest;
import com.acabezas.ehealth_doctor_sdk.model.SignUpResponse;
import com.acabezas.ehealth_doctor_sdk.model.UpdateProfileRequest;
import com.acabezas.ehealth_doctor_sdk.services.GetPacientWaitingListService;
import com.acabezas.ehealth_doctor_sdk.services.GetScheduledAppointmentsService;
import com.acabezas.ehealth_doctor_sdk.services.GetUserProfileService;
import com.acabezas.ehealth_doctor_sdk.services.LoginService;
import com.acabezas.ehealth_doctor_sdk.services.RecoverPasswordService;
import com.acabezas.ehealth_doctor_sdk.services.RemovePacientFromWaitListService;
import com.acabezas.ehealth_doctor_sdk.services.SignUpService;
import com.acabezas.ehealth_doctor_sdk.services.UpdateUserProfileService;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;
import retrofit2.Retrofit;

/**
 * Created by alexandercabezas on 1/5/18.
 */

public class RemoteDataSource implements DoctorDataSource {

    @Override
    public void signUpDoctor(SignUpRequest request, final SignUpDoctorCallback callback) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();
        SignUpService signupService = retrofit.create(SignUpService.class);

        Call<SignUpResponse> call = signupService.signUp(request);
        call.enqueue(new Callback<SignUpResponse>() {

            @Override
            public void onResponse(Call<SignUpResponse> call, Response<SignUpResponse> response) {


                switch (response.code()) {
                    case 200:
                        callback.success(response.body());
                        break;
                    default:
                        callback.failure();
                        break;
                }
            }

            @Override
            public void onFailure(Call<SignUpResponse> call, Throwable t) {
                callback.failure();
            }
        });
    }

    @Override
    public void loginDoctor(LoginRequest request, final LoginDoctorCallback callback) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();

        LoginService loginService = retrofit.create(LoginService.class);

        Call<LoginResponse> call = loginService.login(request);
        call.enqueue(new Callback<LoginResponse>() {

            @Override
            public void onResponse(Call<LoginResponse> call, Response<LoginResponse> response) {

                switch (response.code()) {
                    case 200:
                        callback.success(response.body());
                        break;
                    default:
                        callback.failure();
                        break;
                }
            }

            @Override
            public void onFailure(Call<LoginResponse> call, Throwable t) {
                callback.failure();
            }
        });
    }

    @Override
    public void recoverPassword(RecoverPasswordRequest request, final RecoverPasswordCallback callback) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();

        RecoverPasswordService recoverPasswordService = retrofit.create(RecoverPasswordService.class);

        Call<RecoverPasswordResponse> call = recoverPasswordService.recoverPassword(request);
        call.enqueue(new Callback<RecoverPasswordResponse>() {

            @Override
            public void onResponse(Call<RecoverPasswordResponse> call, Response<RecoverPasswordResponse> response) {


                switch (response.code()) {
                    case 200:
                        callback.success();
                        break;
                    default:
                        callback.failure();
                        break;
                }
            }

            @Override
            public void onFailure(Call<RecoverPasswordResponse> call, Throwable t) {
                callback.failure();
            }
        });
    }


    @Override
    public void getScheduledAppointments(GetAppointmentListRequest request, final GetScheduledAppointmentsCallback callback) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();

        GetScheduledAppointmentsService getScheduledAppointmentsService = retrofit.create(GetScheduledAppointmentsService.class);

        Call<ScheduledAppointmentsResponse> call = getScheduledAppointmentsService.getScheduledAppointments(request.user);
        call.enqueue(new Callback<ScheduledAppointmentsResponse>() {

            @Override
            public void onResponse(Call<ScheduledAppointmentsResponse> call, Response<ScheduledAppointmentsResponse> response) {


                switch (response.code()) {
                    case 200:
                        callback.success(response.body().appointments);
                        break;
                    default:
                        callback.failure();
                        break;
                }
            }

            @Override
            public void onFailure(Call<ScheduledAppointmentsResponse> call, Throwable t) {
                callback.failure();
            }
        });
    }

    @Override
    public void getDoctorData(String user, final GetUserProfileDataCallback callback) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();

        GetUserProfileService getUserProfileService = retrofit.create(GetUserProfileService.class);

        Call<UpdateProfileRequest> call = getUserProfileService.getUserProfile(user);
        call.enqueue(new Callback<UpdateProfileRequest>() {

            @Override
            public void onResponse(Call<UpdateProfileRequest> call, Response<UpdateProfileRequest> response) {


                switch (response.code()) {
                    case 200:
                        callback.success(response.body());
                        break;
                    default:
                        callback.failure();
                        break;
                }
            }

            @Override
            public void onFailure(Call<UpdateProfileRequest> call, Throwable t) {
                callback.failure();
            }
        });
    }

    @Override
    public void updateDoctorProfileData(UpdateProfileRequest request,final UpdateUserProfileDataCallback callback) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();

        UpdateUserProfileService updateUserProfileService = retrofit.create(UpdateUserProfileService.class);

        Call<UpdateProfileRequest> call = updateUserProfileService.updateUserProfile(request, request._id);
        call.enqueue(new Callback<UpdateProfileRequest>() {

            @Override
            public void onResponse(Call<UpdateProfileRequest> call, Response<UpdateProfileRequest> response) {


                switch (response.code()) {
                    case 200:
                        callback.success();
                        break;
                    default:
                        callback.failure();
                        break;
                }
            }

            @Override
            public void onFailure(Call<UpdateProfileRequest> call, Throwable t) {
                callback.failure();
            }
        });
    }


    @Override
    public void removePacientfromWaitList(RemoveUserFromWaitListRequest removeUserFromWaitListRequest) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();

        RemovePacientFromWaitListService removePacient = retrofit.create(RemovePacientFromWaitListService.class);

        Call<GenericResponse> call = removePacient.removePacient(removeUserFromWaitListRequest);
        call.enqueue(new Callback<GenericResponse>() {

            @Override
            public void onResponse(Call<GenericResponse> call, Response<GenericResponse> response) {
            }

            @Override
            public void onFailure(Call<GenericResponse> call, Throwable t) {
            }
        });
    }

    @Override
    public void getPacientWaitingList(final GetPAcientWaitingListCallback callback) {
        Retrofit retrofit = NetworkManagerImpl.getInstance().getRetrofitInstance();

        GetPacientWaitingListService getPacientWaitingListService = retrofit.create(GetPacientWaitingListService.class);

        Call<GetPacientWaitListResponse> call = getPacientWaitingListService.getPacientWaitingList();
        call.enqueue(new Callback<GetPacientWaitListResponse>() {

            @Override
            public void onResponse(Call<GetPacientWaitListResponse> call, Response<GetPacientWaitListResponse> response) {
                callback.success(response.body().pacients);
            }

            @Override
            public void onFailure(Call<GetPacientWaitListResponse> call, Throwable t) {
                callback.failure();
            }
        });
    }
}
